@@ -1,3 +1,28 @@
+# Copyright (c) 2019, Adrian Dusa
+# All rights reserved.
+# 
+# Redistribution and use in source and binary forms, with or without
+# modification, in whole or in part, are permitted provided that the
+# following conditions are met:
+#     * Redistributions of source code must retain the above copyright
+#       notice, this list of conditions and the following disclaimer.
+#     * Redistributions in binary form must reproduce the above copyright
+#       notice, this list of conditions and the following disclaimer in the
+#       documentation and/or other materials provided with the distribution.
+#     * The names of its contributors may NOT be used to endorse or promote products
+#       derived from this software without specific prior written permission.
+# 
+# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
+# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
+# DISCLAIMED. IN NO EVENT SHALL ADRIAN DUSA BE LIABLE FOR ANY
+# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
+# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
+# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
+# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
+# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+
 `convert` <- function(from, to, embed = FALSE, binpath = "", ...) {
     if (missing(from)) {
         cat("\n")
@@ -16,7 +41,6 @@
         targetOS <- other.args$OS
     }
 
-    
     tp_from <- treatPath(from, single = TRUE)
 
     if (identical(toupper(to), "DDI") | identical(toupper(to), "XML")) {
@@ -52,7 +76,7 @@
     }
     
     if (tp_from$fileext == "XML") {
-        codeBook <- getMetadata(from)
+        codeBook <- getMetadata(from, spss = identical(tp_to$fileext, "SAV"))
         
         if (is.element("datafile", names(codeBook[["fileDscr"]]))) {
             data <- codeBook[["fileDscr"]][["datafile"]]
@@ -79,7 +103,7 @@
                 data <- data[, -1, drop = FALSE]
             }
             # return(list(data = data, codeBook = codeBook))
-            data <- convertibble(tibble::as_tibble(data), codeBook$dataDscr)
+            data <- convertibble(tibble::as_tibble(data), codeBook$dataDscr, spss = identical(tp_to$fileext, "SAV"))
         }
     }
     else {
@@ -102,7 +126,6 @@
         codeBook <- getMetadata(data)
     }
 
-    
     if (!identical(binpath, "")) {
         tmpfile <- tempfile()
         tp_temp <- treatPath(tmpfile, check = FALSE)
